@@ -35,7 +35,8 @@ class RDYFile:
                  timedelta_unit: str = 'timedelta64[ns]',
                  strip_timezone: bool = True,
                  filename="",
-                 series: Union[List[Type[TimeSeries]], Type[TimeSeries]] = None):
+                 series: Union[List[Type[TimeSeries]], Type[TimeSeries]] = None,
+                 color: str = None):
         """
 
         Parameters
@@ -165,7 +166,17 @@ class RDYFile:
         else:
             logging.warning("RDYFile instantiated without a path")
 
-        pass
+        # Unique color for each line
+        if not color:
+            while True:
+                self.color = generate_random_color("HEX")
+                if self.color not in config.colors:
+                    config.colors.append(color)
+                    break
+                else:
+                    continue
+        else:
+            self.color = color
 
     # def __getitem__(self, idx):
     #     key = list(self.measurements.keys())[idx]
