@@ -15,13 +15,14 @@ logger = logging.getLogger(__name__)
 
 
 class OSMResultNode:
-    def __init__(self, lat: float, lon: float, value=None, f=None, proc = None, dir: str = ""):
+    def __init__(self, lat: float, lon: float,
+                 value=None, f=None, proc=None, dir: str = "", color: str = None):
         """ Class representing a Node calculated by PyRidy
 
         Parameters
         ----------
-        node_id:
-            ID of the node
+        color: str
+            Node colors
         lat: float
             Latitude of node coordinate
         lon: float
@@ -34,6 +35,7 @@ class OSMResultNode:
         self.f = f
         self.proc = proc
         self.dir = dir
+        self.color = '#CC071E' if not color else color
 
     def __repr__(self):
         return "Result node at (%s, %s)" % (self.lon, self.lat)
