@@ -159,7 +159,7 @@ class ExcitationProcessor(PostProcessor):
             self.campaign.results[ExcitationProcessor]["params"] = params
         pass
 
-    def create_map(self) -> Map:
+    def create_map(self, use_file_color=False) -> Map:
         if not self.campaign.osm:
             raise ValueError("Campaign has no OSM data!")
 
@@ -176,12 +176,13 @@ class ExcitationProcessor(PostProcessor):
         circles = []
         nodes = list(itertools.chain.from_iterable([w.attributes.get("results", []) for w in self.campaign.osm.ways]))
 
+        n: OSMResultNode
         for n in nodes:
             circle = Circle()
             circle.location = n.lon, n.lat
             circle.radius = 2
-            circle.color = "#CC071E"
-            circle.fill_color = "#CC071E"
+            circle.color = n.f.color if use_file_color else n.color
+            circle.fill_color = n.f.color if use_file_color else n.color
             circle.weight = 3
             circle.fill_opacity = 0.1
             circles.append(circle)
